@@ -1,10 +1,11 @@
 package # hide from PAUSE
         Win32;
 use strict;
+use warnings;
 use Config;
+use Exporter ();
 use File::Spec;
 use File::Spec::Functions;
-require Exporter;
 
 {
     no strict;
@@ -715,7 +716,7 @@ SE<eacute>bastien Aperghis-Tramoni E<lt>sebastien@aperghis.netE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 SE<eacute>bastien Aperghis-Tramoni, All Rights Reserved.
+Copyright 2007, 2008 SE<eacute>bastien Aperghis-Tramoni, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
